@@ -41,6 +41,18 @@ class ChronologicalReadDatabaseCache:
         data[self.DATA_KEY] = sorted(values, key=lambda x: x[sort_key])
         data[self.CHRONO_INDEX_KEY] = 0
 
+    def reset_cached_indexes(self, parent=None):
+        """
+        Set the cache index of each cached element at 0
+        :param parent: current cached element
+        """
+        for cached_data in (parent or self.timestamped_sorted_data).values():
+            if isinstance(cached_data, dict):
+                if self.CHRONO_INDEX_KEY in cached_data:
+                    cached_data[self.CHRONO_INDEX_KEY] = 0
+                else:
+                    self.reset_cached_indexes(cached_data)
+
     def get(self, inferior_timestamp, superior_timestamp, identifiers):
         """
         Returns a cache values
